<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Salva messaggi nella Cronologia</translation>
    </message>
    <message>
        <source>Status changes</source>
        <translation>Cambiamenti dello status</translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation>Visualizza cambiamenti dello status</translation>
    </message>
    <message>
        <source>Show status changes in history</source>
        <translation>Visualizza cambiamenti dello status nella Cronologia</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Memorizzi cambiamenti di status</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Memorizzi cambiamenti di status nella Cronologia</translation>
    </message>
    <message>
        <source>Citation</source>
        <translation>Citazione</translation>
    </message>
    <message>
        <source>Message citation in chat window</source>
        <translation>Citazione messaggi nella finestra chat</translation>
    </message>
    <message>
        <source>Don&apos;t cite messages older than</source>
        <translation>Non visualizza messagi più vecchi di</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Mostra cronologia</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Trova</translation>
    </message>
    <message>
        <source>Find &amp;next</source>
        <translation>Trova &amp;successivo</translation>
    </message>
    <message>
        <source>Find &amp;previous</source>
        <translation>Trova &amp;precedente</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Accessibile</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Occupato</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Invisibile</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Fuori linea</translation>
    </message>
    <message>
        <source>Uins</source>
        <translation>Numero GG</translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation>Visualizza cambiamenti dello status</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Cancella Cronologia</translation>
    </message>
    <message>
        <source>Rebuild index</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <source>Clear history?</source>
        <translation>Cancella Cronologia?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Error opening history file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening sms history file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening new history file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening new sms history file </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <source>Show history</source>
        <translation>Mostra cronologia</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Cancella Cronologia</translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation>%1 giorno(i) %2 ora(e)</translation>
    </message>
    <message>
        <source>The following users were deleted:
%0Do you want to remove history as well?</source>
        <translation>Questi contatti erano rimossi:
%0Davvero rimuovere anche la loro Chronologia?</translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <source>Search history</source>
        <translation>Cerca nella Cronologia</translation>
    </message>
    <message>
        <source>&amp;From:</source>
        <translation>&amp;Da:</translation>
    </message>
    <message>
        <source>day</source>
        <translation>giorno</translation>
    </message>
    <message>
        <source>month</source>
        <translation>mese</translation>
    </message>
    <message>
        <source>year</source>
        <translation>anno</translation>
    </message>
    <message>
        <source>hour</source>
        <translation>ora</translation>
    </message>
    <message>
        <source>minute</source>
        <translation>minuto</translation>
    </message>
    <message>
        <source>Find Criteria</source>
        <translation>Parametri Ricerca</translation>
    </message>
    <message>
        <source>&amp;Pattern</source>
        <translation>&amp;Modello</translation>
    </message>
    <message>
        <source>&amp;Status</source>
        <translation>&amp;Status</translation>
    </message>
    <message>
        <source>Pattern</source>
        <translation>Modello</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>&amp;Reverse find</source>
        <translation>&amp;Ricerca all&apos;indietro</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Trova</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
</context>
</TS>
